@@ -11,3 +11,8 @@ dnf install -y dnf5-plugins || true
 
 dnf install -y dnf-plugins-core git rpm-build tree which \
                python3 cmake make gcc gcc-c++
+
+# Additional packages for docs build
+if [[ "$1" == "--with-docs" ]]; then
+  dnf install -y python3-sphinx python3-pip python3-breathe
+fi
