@@ -39,12 +39,26 @@ public:
   // write from content provider
   virtual dav_ssize_t writeFromProvider(IOChainContext & iocontext, ContentProvider &provider);
 
+  // Returns uploadId
+  virtual std::string initiateMultipart(IOChainContext & iocontext) override;
+
+  // Given the upload id and part#, write the given buffer and add the
+  // object id to the etags vector.
+  virtual bool writeFromBuffer(IOChainContext&  iocontext, const char* buff,
+                               dav_size_t size, const std::string& uploadId,
+                               std::vector<std::string>& etags, int partNumber)
+                               override;
+
+  // Given upload id and last chunk, commit chunks
+  virtual bool commitChunks(IOChainContext& iocontext,
+                            const std::string& uploadId,
+                            const std::vector<std::string>& etags) override;
+
   void performUgrS3MultiPart(IOChainContext & iocontext, const std::string &posturl, const std::string &pluginId, ContentProvider &provider, DavixError **err);
 
 private:
 
   // Returns uploadId
-  std::string initiateMultipart(IOChainContext & iocontext);
   std::string initiateMultipart(IOChainContext & iocontext, const Uri &url);
 
   DynafedUris retrieveDynafedUris(IOChainContext & iocontext, const std::string &uploadId, const std::string &pluginId, size_t nchunks);
@@ -56,7 +70,6 @@ private:
 
 
   // Given upload id and last chunk, commit chunks
-  void commitChunks(IOChainContext & iocontext,  const std::string &uploadId, const std::vector<std::string> &etags);
   void commitChunks(IOChainContext & iocontext,  const Uri &uri, const std::vector<std::string> &etags);
 };
 
