@@ -1,6 +1,7 @@
 /*
  * This File is part of Davix, The IO library for HTTP based protocols
- * Copyright (C) 2013  Adrien Devresse <adrien.devresse@cern.ch>, CERN
+ * Copyright (C) CERN 2013
+ * Author: Adrien Devresse <adrien.devresse@cern.ch>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -55,9 +56,7 @@ public:
     // read to fd
     virtual dav_ssize_t readToFd(IOChainContext & iocontext, int fd, dav_size_t size);
 
-    // position independant write operation,
-    // similar to pwrite do not need open() before
-    virtual dav_ssize_t writeFromFd(IOChainContext & iocontext, int fd, dav_size_t size);
+    virtual dav_ssize_t writeFromProvider(IOChainContext & iocontext, ContentProvider &provider);
 
 private:
 
@@ -110,9 +109,9 @@ protected:
     advise_t _last_advise;
 
     // locker
-    boost::recursive_mutex _rwlock;
+    std::recursive_mutex _rwlock;
     // write cache
-    boost::scoped_ptr<IOBufferLocalFile> _local;
+    std::unique_ptr<IOBufferLocalFile> _local;
 
     dav_off_t _read_pos; //curent read file offset
     bool _read_endfile;
@@ -134,7 +133,7 @@ private:
 int get_valid_cache_file(FILE** stream, DavixError** err);
 
 
-dav_ssize_t read_segment_request(HttpRequest* req, void* buffer, dav_size_t size_read,  dav_off_t off_set, DavixError**err);
+dav_ssize_t read_segment_request(HttpRequest* req, void* buffer, dav_size_t size_read, DavixError**err);
 
 
 } // namespace Davix
