@@ -25,7 +25,6 @@
 #include <params/davixrequestparams.hpp>
 #include <libs/time_utils.h>
 #include <utils/davix_gcloud_utils.hpp>
-#include <utils/davix_cs3_utils.hpp>
 
 
 
@@ -90,8 +89,8 @@ struct RequestParamsInternal{
         _redirection(true),
         _recursive_mode(false),
         _s3_listing_mode(S3ListingMode::Hierarchical),
-        _s3_max_key_entries(10000),
         _swift_listing_mode(SwiftListingMode::Hierarchical),
+        _s3_max_key_entries(10000),
         _ca_path(),
         _x509_data(),
         _idlogpass(),
@@ -100,7 +99,6 @@ struct RequestParamsInternal{
         _aws_cred(),
         _aws_region(),
         _aws_token(),
-        _reva_creds(),
         _aws_alternate(false),
         _azure_key(),
         _gcloud_creds(),
@@ -143,8 +141,8 @@ struct RequestParamsInternal{
         _redirection(param_private._redirection),
         _recursive_mode(param_private._recursive_mode),
         _s3_listing_mode(param_private._s3_listing_mode),
-        _s3_max_key_entries(param_private._s3_max_key_entries),
         _swift_listing_mode(param_private._swift_listing_mode),
+        _s3_max_key_entries(param_private._s3_max_key_entries),
         _ca_path(param_private._ca_path),
         _x509_data(param_private._x509_data),
         _idlogpass(param_private._idlogpass),
@@ -153,7 +151,6 @@ struct RequestParamsInternal{
         _aws_cred(param_private._aws_cred),
         _aws_region(param_private._aws_region),
         _aws_token(param_private._aws_token),
-        _reva_creds(param_private._reva_creds),
         _aws_alternate(param_private._aws_alternate),
         _azure_key(param_private._azure_key),
         _gcloud_creds(param_private._gcloud_creds),
@@ -205,7 +202,6 @@ struct RequestParamsInternal{
     std::pair<AwsSecretKey, AwsAccessKey> _aws_cred;
     AwsRegion _aws_region;
     AwsToken _aws_token;
-    reva::Credentials _reva_creds;
     bool _aws_alternate;
     AzureSecretKey _azure_key;
     gcloud::Credentials _gcloud_creds;
@@ -353,7 +349,7 @@ const authFunctionClientCertX509 & RequestParams::getClientCertFunctionX509() co
     return x509->_x509_fun;
 }
 
-/// return the current client side callback for authentification with the current user data
+/// return the current client side callback for authentication with the current user data
 std::pair<authCallbackClientCertX509,void*> RequestParams::getClientCertCallbackX509() const{
     X509Data* x509 = X509Data::instance(d_ptr->_x509_data);
     return x509->_pair;
@@ -367,7 +363,7 @@ void RequestParams::setClientLoginPasswordCallback(authCallbackLoginPasswordBasi
     d_ptr->_call_loginpswwd_userdata = userdata;
 }
 
-/// return the current client side callback for authentification with the current user data
+/// return the current client side callback for authentication with the current user data
 std::pair<authCallbackLoginPasswordBasic,void*> RequestParams::getClientLoginPasswordCallback() const{
     return std::pair<authCallbackLoginPasswordBasic,void*>(d_ptr->_call_loginpswwd, d_ptr->_call_loginpswwd_userdata);
 }
@@ -397,21 +393,6 @@ const AwsToken & RequestParams::getAwsToken() const {
     return d_ptr->_aws_token;
 }
 
-void RequestParams::setRevaCredentials(reva::Credentials &credentials) {
-        d_ptr->_reva_creds = credentials;
-}
-void RequestParams::getRevaCredentialMap(reva::CredentialMap & cmap) {
-        d_ptr->_reva_creds.getCredentialMap(cmap);
-}
-
-const RevaToken RequestParams::getRevaToken(std::string uri) const& {
-        return d_ptr->_reva_creds.getToken(uri);
-}
-
-const reva::Credentials & RequestParams::getRevaCredentials() const {
-        return d_ptr->_reva_creds;
-}
-
 void RequestParams::setAwsAlternate(const bool &alternate) {
     d_ptr->_aws_alternate = alternate;
 }
