@@ -17,13 +17,14 @@ using namespace Davix;
 
 
 int mycred_auth_callback_x509(void* userdata, const SessionInfo & info, X509Credential * cred, DavixError** err){
+    (void) info;
     Davix::DavixError* tmp_err= NULL;
 
     std::string path((char*) userdata);
     int ret = cred->loadFromFileP12( path, "", &tmp_err);
 
     if(ret != 0){
-        fprintf(stderr, " FATAL authentification Error : %s", tmp_err->getErrMsg().c_str());
+        fprintf(stderr, " FATAL authentication Error : %s", tmp_err->getErrMsg().c_str());
         DavixError::propagateError(err, tmp_err);
     }
     return ret;
@@ -37,6 +38,12 @@ char* generate_random_uri(const char* uri_dir, const char* prefix, char* buff, s
     return buff;
 }
 
+Davix::Uri generate_random_uri(const Davix::Uri & url_directory, const std::string & prefix){
+    std::ostringstream ss;
+    ss << url_directory << "/" << prefix << static_cast<int>(getpid()) << static_cast<long>(time(NULL)) << static_cast<long>(rand());
+    return Davix::Uri(ss.str());
+}
+
 void configure_grid_env(char * cert_path, RequestParams&  p){
 
     if(strcmp(cert_path, "proxy") == 0){ // VOMS PROXY MODE
